@@ -196,54 +196,54 @@ def _get_resources_from_list_function(response, method):
     logger.info("===============list function response==============")
     logger.info(response)
     if method == 'list_buckets':
-        return [x['Name'] for x in response['Buckets']]
+        return [x['Name'] for x in response.get('Buckets', [])]
     elif method == 'describe_instances':
         final_list = []
-        for reservation in response['Reservations']:
+        for reservation in response.get('Reservations', []):
             for instance in reservation['Instances']:
                 final_list.append(instance['InstanceId'])
         return final_list
     elif method == 'describe_db_instances':
-        return [x['DBInstanceIdentifier'] for x in response['DBInstances']]
+        return [x['DBInstanceIdentifier'] for x in response.get('DBInstances', [])]
     elif method == 'describe_db_clusters':
-        return [x['DBClusterIdentifier'] for x in response['DBClusters']]
+        return [x['DBClusterIdentifier'] for x in response.get('DBClusters', [])]
     elif method == 'describe_db_parameter_groups':
-        return [x['DBParameterGroupName'] for x in response['DBParameterGroups']]
+        return [x['DBParameterGroupName'] for x in response.get('DBParameterGroups', [])]
     elif method == 'describe_global_clusters':
-        return [x['GlobalClusterIdentifier'] for x in response['GlobalClusters']]
+        return [x['GlobalClusterIdentifier'] for x in response.get('GlobalClusters', [])]
     elif method == 'describe_target_groups':
-        return [x['TargetGroupArn'] for x in response['TargetGroups']]
+        return [x['TargetGroupArn'] for x in response.get('TargetGroups', [])]
     elif method == 'describe_load_balancers':
         if "LoadBalancerDescriptions" in response.keys():
             return [x.get('LoadBalancerName') for x in response.get('LoadBalancerDescriptions', [])]
         elif "LoadBalancers" in response.keys():
             return [x.get('LoadBalancerArn') for x in response.get('LoadBalancers', [])]
     elif method == 'list_certificates':
-        return [x['CertificateArn'] for x in response['CertificateSummaryList']]     
+        return [x['CertificateArn'] for x in response.get('CertificateSummaryList', [])]     
     elif method == 'list_backup_vaults':
-        return [x['BackupVaultName'] for x in response['BackupVaultList']]
+        return [x['BackupVaultName'] for x in response.get('BackupVaultList', [])]
     elif method == 'list_servers':
-        return [x['ServerId'] for x in response['Servers']]          
+        return [x['ServerId'] for x in response.get('Servers', [])]          
     elif method == 'list_stacks':
-        return [x['StackName'] for x in response['StackSummaries']]        
+        return [x['StackName'] for x in response.get('StackSummaries', [])]        
     elif method == 'list_trails':
-        return [x['Name'] for x in response['Trails']]        
+        return [x['Name'] for x in response.get('Trails', [])]        
     elif method in ['describe_stacks', 'list_trails']:
-        return [x['StackName'] for x in response['Stacks']]        
+        return [x['StackName'] for x in response.get('Stacks', [])]        
     elif method == 'get_rest_apis':
-        return [x['id'] for x in response['items']]   
+        return [x['id'] for x in response.get('items', [])]   
     elif method == 'list_users':
-        return [x['UserName'] for x in response['Users']]
+        return [x['UserName'] for x in response.get('Users', [])]
     elif method == 'list_roles':
-        return [x['RoleName'] for x in response['Roles']]     
+        return [x['RoleName'] for x in response.get('Roles', [])]     
     elif method == 'list_hosted_zones':
-        return [x['Id'] for x in response['HostedZones']]
+        return [x['Id'] for x in response.get('HostedZones', [])]
     elif method == 'list_keys':
-        return [x.get('KeyId') for x in response['Keys']]
+        return [x.get('KeyId') for x in response.get('Keys', [])]
     elif method == 'list_tables':
         return response.get("TableNames", [])
     elif method == 'list_backups':
-        return [x.get('BackupArn',"") for x in response['BackupSummaries']]
+        return [x.get('BackupArn',"") for x in response.get('BackupSummaries', [])]
     elif method == 'list_task_definitions':
         return response.get('taskDefinitionArns', [])
     elif method == 'list_clusters':
@@ -255,93 +255,95 @@ def _get_resources_from_list_function(response, method):
         logger.info("*****************%s", clusters)
         return clusters
     elif method == 'describe_replication_groups':
-        return [x.get('ReplicationGroupId') for x in response['ReplicationGroups']]
+        return [x.get('ReplicationGroupId') for x in response.get('ReplicationGroups', [])]
     elif method == 'list_streams':
         return response.get("StreamNames", [])
     elif method == 'list_functions':
-        return [x.get('FunctionName',"") for x in response['Functions']]
+        return [x.get('FunctionName',"") for x in response.get('Functions', [])]
     elif method == 'describe_clusters':
         clusters = []
-        clusters.extend([x.get('ClusterIdentifier', x.get("ClusterName", "")) for x in response['Clusters']])
+        clusters.extend([x.get('ClusterIdentifier', x.get("ClusterName", "")) for x in response.get('Clusters', [])])
         return clusters
     elif method == 'list_topics':
-        return [x.get('TopicArn',"") for x in response['Topics']]
+        return [x.get('TopicArn',"") for x in response.get('Topics', [])]
     elif method == 'list_subscriptions':
-        return [x.get('SubscriptionArn',"") for x in response['Subscriptions']]
+        return [x.get('SubscriptionArn',"") for x in response.get('Subscriptions', [])]
     elif method == 'list_queues':
         return response.get("QueueUrls", [])
     elif method == 'list_domain_names':
-        return [x.get('DomainName') for x in response['DomainNames']] 
+        return [x.get('DomainName') for x in response.get('DomainNames', [])] 
     elif method == 'describe_configuration_recorders':
-        return [x.get('name') for x in response['ConfigurationRecorders']] 
+        return [x.get('name') for x in response.get('ConfigurationRecorders', [])] 
     elif method == 'list_distributions':
-        return [x.get('Id') for x in response['DistributionList']['Items']]
+        return [x.get('Id') for x in response.get('DistributionList', [])['Items']]
     elif method == 'describe_vpn_gateways':
-        return [x.get('VpnGatewayId') for x in response['VpnGateways']]
+        return [x.get('VpnGatewayId') for x in response.get('VpnGateways', [])]
     elif method == 'describe_file_systems':
-        return [x.get('FileSystemId') for x in response['FileSystems']]
+        return [x.get('FileSystemId') for x in response.get('FileSystems', [])]
     elif method == 'describe_parameters':
-        return [x.get('Name') for x in response['Parameters']]
+        return [x.get('Name') for x in response.get('Parameters', [])]
     elif method == 'describe_cache_subnet_groups':
-        return [x.get('CacheSubnetGroupName') for x in response['CacheSubnetGroups']]
+        return [x.get('CacheSubnetGroupName') for x in response.get('CacheSubnetGroups', [])]
     elif method == 'describe_route_tables':
-        return [x.get('RouteTableId') for x in response['RouteTables']]
+        return [x.get('RouteTableId') for x in response.get('RouteTables', [])]
     elif method == 'describe_network_acls':
-        return [x.get('NetworkAclId') for x in response['NetworkAcls']]
+        return [x.get('NetworkAclId') for x in response.get('NetworkAcls', [])]
     elif method == 'describe_event_subscriptions':
-        return [x.get('EventSubscriptionArn').split(':')[-1] for x in response['EventSubscriptionsList']]
+        return [x.get('EventSubscriptionArn').split(':')[-1] for x in response.get('EventSubscriptionsList', [])]
     elif method == 'describe_db_snapshots':
-        return [x.get('DBSnapshotIdentifier') for x in response['DBSnapshots']]
+        return [x.get('DBSnapshotIdentifier') for x in response.get('DBSnapshots', [])]
     elif method == 'list_web_acls':
-        return [x.get("Name") for x in response['WebACLs']]
+        return [x.get("Name") for x in response.get('WebACLs', [])]
     elif method == 'describe_repositories':
-        return [x.get("repositoryName") for x in response['repositories']]
+        return [x.get("repositoryName") for x in response.get('repositories', [])]
     elif method == 'list_ledgers':
-        return [x.get("Name") for x in response['Ledgers']]
+        return [x.get("Name") for x in response.get('Ledgers', [])]
     elif method == 'describe_db_cluster_parameter_groups':
-        return [x.get("DBClusterParameterGroupName") for x in response['DBClusterParameterGroups']]
+        return [x.get("DBClusterParameterGroupName") for x in response.get('DBClusterParameterGroups', [])]
     elif method == 'list_work_groups':
-        return [x.get("Name") for x in response['WorkGroups']]
+        return [x.get("Name") for x in response.get('WorkGroups', [])]
     elif method == 'list_databases':
-        return [x.get("DatabaseName") for x in response['Databases']]
+        return [x.get("DatabaseName") for x in response.get('Databases', [])]
     elif method == 'describe_endpoints':
-        return [x.get("EndpointIdentifier") for x in response['Endpoints']]
+        return [x.get("EndpointIdentifier") for x in response.get('Endpoints', [])]
     elif method == 'describe_security_groups':
-        return [x.get("GroupId") for x in response['SecurityGroups']]
+        return [x.get("GroupId") for x in response.get('SecurityGroups', [])]
     elif method == 'list_secrets':
-        return [x.get("Name") for x in response['SecretList']]
+        return [x.get("Name") for x in response.get('SecretList', [])]
     elif method == 'describe_log_groups':
-        return [x.get("logGroupName") for x in response['logGroups']]
+        return [x.get("logGroupName") for x in response.get('logGroups', [])]
     elif method == 'describe_workspaces':
-        return [x.get("WorkspaceId") for x in response['Workspaces']]
+        return [x.get("WorkspaceId") for x in response.get('Workspaces', [])]
     elif method == 'get_data_catalog_encryption_settings':
         return [""]
     elif method == 'get_security_configurations':
-        return [x.get("Name") for x in response['SecurityConfigurations']]
+        return [x.get("Name") for x in response.get('SecurityConfigurations', [])]
     elif method == 'describe_launch_configurations':
-        return [x.get("LaunchConfigurationName") for x in response['LaunchConfigurations']]
+        return [x.get("LaunchConfigurationName") for x in response.get('LaunchConfigurations', [])]
     elif method == 'describe_auto_scaling_groups':
-        return [x.get("AutoScalingGroupName") for x in response['AutoScalingGroups']]
+        return [x.get("AutoScalingGroupName") for x in response.get('AutoScalingGroups', [])]
     elif method == 'describe_configuration_aggregators':
-        return [x.get("ConfigurationAggregatorName") for x in response['ConfigurationAggregators']]
+        return [x.get("ConfigurationAggregatorName") for x in response.get('ConfigurationAggregators', [])]
     elif method == 'describe_configuration_recorders':
-        return [x.get("name") for x in response['ConfigurationRecorders']]
+        return [x.get("name") for x in response.get('ConfigurationRecorders', [])]
     elif method == 'list_streams':
-        return response["StreamNames"]
+        return response.get("StreamNames", [])
     elif method == 'list_brokers':
-        return [x.get("BrokerId") for x in response['BrokerSummaries']]
+        return [x.get("BrokerId") for x in response.get('BrokerSummaries', [])]
     elif method == 'list_hosted_zones':
-        return [x.get("Id") for x in response['HostedZones']]
+        return [x.get("Id") for x in response.get('HostedZones', [])]
     elif method == 'list_notebook_instances':
-        return [x.get("NotebookInstanceName") for x in response['NotebookInstances']]
+        return [x.get("NotebookInstanceName") for x in response.get('NotebookInstances', [])]
     elif method == 'list_projects':
-        return response["projects"]
+        return response.get("projects", [])
     elif method == 'list_pipelines':
-        return [x.get("name") for x in response['pipelines']]
+        return [x.get("name") for x in response.get('pipelines', [])]
     elif method == 'list_applications':
-        return response["applications"]
+        return response.get("applications", [])
     elif method == 'list_policies':
-        return [x.get("Arn") for x in response['Policies']]
+        return [x.get("Arn") for x in response.get('Policies', [])]
+    elif method == 'list_rules_packages':
+        return response.get("rulesPackageArns", [])
     else:
         return []
 
@@ -808,6 +810,10 @@ def _get_function_kwargs(arn_str, function_name, existing_json, kwargs={}):
         return {
             'applicationNames': [resource_id]
         }
+    elif client_str == "inspector" and function_name == "describe_rules_packages":
+        return {
+            'rulesPackageArns': [arn_str]
+        }
     else:
         return {}
 
